/***************************************************************************
                          cencrypt.h  -  description
                             -------------------
    begin                : Sat Sep 29 2001
    copyright            : (C) 2001-2003 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CENCRYPT_H
#define CENCRYPT_H

/**
  *@author Mathias Kster
  */

#include <dclib/dcos.h>
#include <dclib/core/cstring.h>

class DLL_EXPORT CEncrypt {
public: 
	CEncrypt();
	virtual ~CEncrypt();

	/** */
	void Encrypt( CString s, CString & d );
	/** */
	void Encode( int c, CString & d );
	/** */
	CString Encode( CString s );
	/** */
	CString Decode( CString s );
};

#endif
